package com.iconplus.smartproc.service.rksdaftarisi;

import com.iconplus.smartproc.helper.model.Pagination;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.projection.RksDaftarIsiView;
import com.iconplus.smartproc.model.request.RksDaftarRequest;
import com.iconplus.smartproc.model.response.ListRksDaftarIsiResponse;
import com.iconplus.smartproc.model.response.RksDaftarResponse;
import com.iconplus.smartproc.repository.RksDaftarRepository;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class GetListRksDaftarIsiService implements BaseService<RksDaftarRequest, ListRksDaftarIsiResponse> {

    private final RksDaftarRepository rksDaftarRepository;
    public GetListRksDaftarIsiService(RksDaftarRepository rksDaftarRepository) {
        this.rksDaftarRepository = rksDaftarRepository;
    }

    @Override
    public ListRksDaftarIsiResponse execute(RksDaftarRequest input) {

        List<RksDaftarResponse> rksDaftarResponseList = new ArrayList<>();
        var rksDaftarIsiViews= rksDaftarRepository.getListRksDaftarIsi(input.getPageable());
        for (RksDaftarIsiView rksDaftarIsiView : rksDaftarIsiViews) {
            RksDaftarResponse rksDaftarResponse = RksDaftarResponse.builder()
                    .id(rksDaftarIsiView.getId())
                    .kodeTemplate(rksDaftarIsiView.getKodeTemplate())
                    .namaTemplate(rksDaftarIsiView.getNamaTemplate())
                    .metodePengadaanId(rksDaftarIsiView.getMetodePengadaanId())
                    .metodePengadaan(rksDaftarIsiView.getMetodePengadaan())
                    .versi(rksDaftarIsiView.getVersi())
                    .build();
            rksDaftarResponseList.add(rksDaftarResponse);
        }

        return ListRksDaftarIsiResponse.builder()
                .data(rksDaftarResponseList)
                .pagination(Pagination.builder()
                        .pageSize(input.getPageable().getPageSize())
                        .currentPage(input.getPageable().getPageNumber())
                        .totalPages(rksDaftarIsiViews.getTotalPages())
                        .totalRecords(rksDaftarIsiViews.getTotalElements())
                        .isFirstPage(rksDaftarIsiViews.isFirst())
                        .isLastPage(rksDaftarIsiViews.isLast())
                        .build())
                .build();
    }
}
